@@ -1412,7 +1412,7 @@ stream_metadata(pmDiscover *p, int mtype, uint32_t *buf, size_t len)
 	if (pmDebugOptions.discovery)
 	    fprintf(stderr, "%s: type %s, len = %zu\n", __FUNCTION__,
 		mtype == (PM_LOG_MAGIC | PM_LOG_VERS02) ? "PM_LOG_MAGICv2"
-		: (type == (PM_LOG_MAGIC | PM_LOG_VERS03) ? "PM_LOG_MAGICv3"
+		: (mtype == (PM_LOG_MAGIC | PM_LOG_VERS03) ? "PM_LOG_MAGICv3"
 		: "UNKNOWN"), len);
 	return PM_ERR_LOGREC;
     }
@@ -2345,7 +2345,7 @@ pmDiscoverRegister(const char *dir, pmDiscoverModule *module,
 		return -ENOMEM;
 	    discoverCallBackTable = cbp;
 	    if (pmDebugOptions.discovery)
-		fprintf(stderr, "%s: new handle [%d] for callbacks %p\n",
+		fprintf(stderr, "%s: new handle [%d] for callbacks " PRINTF_P_PFX "%p\n",
 			__FUNCTION__, avail_handle, callbacks);
 	}
 	handle = avail_handle;
@@ -2642,7 +2642,7 @@ pmDiscoverSetup(pmDiscoverModule *module, pmDiscoverCallBacks *cbs, void *arg)
 
     /* prepare for optional metric and indom exclusion */
     if ((option = pmIniFileLookup(config, "discover", "exclude.metrics"))) {
-	if ((data->pmids = dictCreate(&intKeyDictCallBacks, NULL)) == NULL)
+	if ((data->pmids = dictCreate(&intKeyDictCallBacks)) == NULL)
 	    return -ENOMEM;
 	/* parse comma-separated metric name glob patterns, in 'option' */
 	if ((ids = sdssplitlen(option, sdslen(option), ",", 1, &nids))) {
@@ -2653,7 +2653,7 @@ pmDiscoverSetup(pmDiscoverModule *module, pmDiscoverCallBacks *cbs, void *arg)
 	}
     }
     if ((option = pmIniFileLookup(config, "discover", "exclude.indoms"))) {
-	if ((data->indoms = dictCreate(&intKeyDictCallBacks, NULL)) == NULL)
+	if ((data->indoms = dictCreate(&intKeyDictCallBacks)) == NULL)
 	    return -ENOMEM;
 	/* parse comma-separated indoms in 'option', convert to pmInDom */
 	if ((ids = sdssplitlen(option, sdslen(option), ",", 1, &nids))) {
